@@ -8,7 +8,7 @@ use self::slides::slides;
 use self::visible_title::visible_title;
 use self::wrap_string::WrapString;
 use std::io::{Error as IoError, ErrorKind};
-use yaml_peg::{indicated_msg, parse, repr::RcRepr, Anchors, Array, Node};
+use yaml_peg::{indicated_msg, parse, repr::RcRepr, Anchors, Node, Seq};
 
 mod background;
 mod content;
@@ -23,27 +23,15 @@ pub(crate) mod wrap_string;
 const TEMPLATE: &str = include_str!("../assets/template.html");
 const ICON: &str = "help/icon.png";
 const RELOAD: &str = "\
-setInterval(function() {
-    $.ajax({
-        url: '/changed/',
-        contentType: 'json',
-        success: data => {
-            if (window.modified === undefined)
-                window.modified = data['modified'];
-            if (data['modified'] > window.modified) {
-                window.modified = data['modified'];
-                location.reload();
-            }
-        }
-    });
-}, 500);";
+let ws = new WebSocket(\"ws://\" + window.location.host + \"/ws/\");
+        ws.onmessage = _ => location.reload();";
 
-fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str, reload: bool) -> Result<String, Error> {
+fn load_main(yaml: Seq<RcRepr>, v: &Anchors, mount: &str, reload: bool) -> Result<String, Error> {
     let meta = &yaml[0];
     let bg = Background::new(meta)?;
     let outline = meta.get_default("outline", true, Node::as_bool)?;
     let style = meta.get_default("style", "", Node::as_str)?;
-    let (doc, title) = slides(yaml[1].as_array()?, v, bg, outline)?;
+    let (doc, title) = slides(yaml[1].as_seq()?, v, bg, outline)?;
     let title = meta.get_default("title", title.as_ref(), Node::as_str)?;
     let description = meta.get_default("description", title.as_ref(), Node::as_str)?;
     let author = meta.get_default("author", "", Node::as_str)?;
@@ -52,7 +40,6 @@ fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str, reload: bool) -> Res
     let (plugin_names, plugin_files) = js_plugin(meta)?;
     let reload_script = if reload { RELOAD } else { "" };
     Ok(TEMPLATE
-        .to_string()
         .replace("{%icon}", meta.get_default("icon", ICON, Node::as_str)?)
         .replace("{%lang}", meta.get_default("lang", "en", Node::as_str)?)
         .replace("{%title}", &title.escape())
